@@ -6,12 +6,13 @@ use Carp qw/confess/;
 use IO::Socket::INET;
 use Scalar::Util qw/reftype/;
 
-$Net::Graphite::VERSION = '0.16';
+$Net::Graphite::VERSION = '0.17';
 
 our $TEST = 0;   # if true, don't send anything to graphite
 
 sub new {
     my $class = shift;
+    my %args = @_ == 1 && ref $_[0] eq 'HASH' ? %{$_[0]} : @_;
     return bless {
         host                 => '127.0.0.1',
         port                 => 2003,
@@ -21,7 +22,7 @@ sub new {
         timeout              => 1,
         # path
         # transformer
-        @_,
+        %args,
         # _socket
     }, $class;
 }
@@ -150,8 +151,8 @@ sub connect {
 # if you need to close/flush for some reason
 sub close {
     my $self = shift;
-    $self->{_socket}->close();
-    $self->{_socket} = undef;
+    return unless my $socket = delete $self->{_socket};
+    $socket->close();
 }
 
 sub trace {
